/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef __NET_CONFIG_GDBUS_H__
#define __NET_CONFIG_GDBUS_H__

#include <glib.h>
#include <gio/gio.h>

#include "netconf.h"

#define GMAINTIMEOUT 10000
#define DBUS_REPLY_TIMEOUT (120 * 1000)

#define NETCONFIG_SERVICE "net.netconfig"

/* wifi */
#define NETCONFIG_WIFI_PATH "/net/netconfig/wifi"
#define NETCONFIG_WIFI_INTERFACE "net.netconfig.wifi"

#define GET_WIFI_STATE "GetWifiState"
#define LOAD_DRIVER "LoadDriver"
#define REMOVE_DRIVER "RemoveDriver"
#define IS_IP_CONFLICT_DETECT_ENABLED "IsIpConflictDetectEnabled"
#define SET_BGSCAN "SetBgscan"
#define GET_AUTOSCAN "GetAutoscan"
#define GET_IP_CONFLICT_STATE "GetIpConflictState"
#define GET_IP_CONFLICT_PERIOD "GetIpConflictPeriod"
#define GET_AUTOSCANMODE "GetAutoscanmode"
#define REQUEST_WPS_CONNECT "RequestWpsConnect"
#define NETLINK_SCAN "NetlinkScan"
#define GET_PASSPOINT "GetPasspoint"
#define SET_PASSPOINT "SetPasspoint"
#define GET_CONFIGIDS "GetConfigIds"
#define SAVE_CONFIGURATION "SaveConfiguration"
#define SAVE_EAP_CONFIGURATION "SaveEapConfiguration"
#define SET_IP_CONFLICT_PERIOD "SetIpConflictPeriod"
#define REMOVE_CONFIGURATION "RemoveConfiguration"
#define LOAD_CONFIGURATION "LoadConfiguration"
#define LOAD_EAP_CONFIGURATION "LoadEapConfiguration"
#define SET_CONFIG_FIELD "SetConfigField"
#define GET_CONFIG_PASSPHRASE "GetConfigPassphrase"
#define CREATE_EAP_CONFIG "CreateEapConfig"
#define DELETE_EAP_CONFIG "DeleteEapConfig"
#define IP_CONFLICT_SET_ENABLE "IpConflictSetEnable"
#define GET_SIM_IMSI "GetSimImsi"
#define REQ_SIM_AUTH "ReqSimAuth"
#define REQ_AKA_AUTH "ReqAkaAuth"
#define GET_SIM_AUTH "GetSimAuth"
#define CHECK_BLACKLIST "CheckBlackList"
#define TDLS_DISCONNECT "TdlsDisconnect"
#define TDLS_CONNECTED_PEER "TdlsConnectedPeer"
#define TDLS_CONNECT "TdlsConnect"
#define TDLS_DISCOVER "TdlsDiscover"
#define TDLS_CHANNEL_SWITCH "TdlsChannelSwitch"
#define TDLS_CANCEL_CHANNEL_SWITCH "TdlsCancelChannelSwitch"
#define ADD_VSIE "AddVsie"
#define GET_VSIE "GetVsie"
#define REMOVE_VSIE "RemoveVsie"
#define ENCRYPT_PASSPHRASE "EncryptPassphrase"
#define DECRYPT_PASSPHRASE "DecryptPassphrase"

#define NETCONFIG_WIFI_FIRMWARE_INTERFACE "net.netconfig.wifi.Firmware"

#define WIFI_FIRMWARE_STOP "Stop"
#define WIFI_FIRMWARE_START "Start"

/* vpn service */
#define NETCONFIG_VPNSVC_PATH "/net/netconfig/vpnsvc"
#define NETCONFIG_VPNSVC_INTERFACE "net.netconfig.vpnsvc"

#define VPN_INIT "vpn_init"
#define VPN_DEINIT "vpn_deinit"
#define VPN_PROTECT "vpn_protect"
#define VPN_UP "vpn_up"
#define VPN_DOWN "vpn_down"
#define VPN_BLOCK_NETWORKS "vpn_block_networks"
#define VPN_UNBLOCK_NETWORKS "vpn_unblock_networks"
#define VPN_UPDATE_SETTINGS "vpn_update_settings"
#define VPN_ADD_ROUTE "vpn_add_route"
#define VPN_REMOVE_ROUTE "vpn_remove_route"
#define VPN_ADD_DNS_SERVER "vpn_add_dns_server"
#define VPN_REMOVE_DNS_SERVER "vpn_remove_dns_server"

/* network state */
#define NETCONFIG_NETWORK_PATH "/net/netconfig/network"
#define NETCONFIG_NETWORK_INTERFACE "net.netconfig.network"
#define NETCONFIG_TCPDUMP_INTERFACE "net.netconfig.tcpdump"

#define ADD_ROUTE "AddRoute"
#define REMOVE_ROUTE "RemoveRoute"
#define ETHERNET_CABLE_STATE "EthernetCableState"
#define CHECK_GET_PRIVILEGE "CheckGetPrivilege"
#define CHECK_PROFILE_PRIVILEGE "CheckProfilePrivilege"
#define CHECK_INTERNET_Privilege "CheckInternetPrivilege"
#define LAUNCH_MDNS "LaunchMdns"
#define DEVICE_POLICY_SET_WIFI "DevicePolicySetWifi"
#define DEVICE_POLICY_GET_WIFI "DevicePolicyGetWifi"
#define DEVICE_POLICY_SET_WIFI_PROFILE "DevicePolicySetWifiProfile"
#define DEVICE_POLICY_GET_WIFI_PROFILE "DevicePolicyGetWifiProfile"
#define GET_METERED_INFO "GetMeteredInfo"
#define PREFERRED_IPV6_ADDRESS "PreferredIpv6Address"
#define GET_TCP_DUMPSTATE "GetTCPDumpState"
#define START_TCP_DUMP "StartTCPDump"
#define STOP_TCP_DUMP "StopTCPDump"

/* mptcp */
#define NETCONFIG_MPTCP_PATH "/net/netconfig/mptcp"
#define NETCONFIG_MPTCP_INTERFACE "net.netconfig.mptcp"

#define MPTCP_SUPPORTED "IsSupported"
#define MPTCP_SET_ENABLE "SetEnabled"
#define MPTCP_GET_ENABLED "GetEnabled"
#define MPTCP_SET_PATH_MANAGER "SetPathManager"
#define MPTCP_GET_PATH_MANAGER "GetPathManager"
#define MPTCP_SET_SCHEDULER "SetScheduler"
#define MPTCP_GET_SCHEDULER "GetScheduler"

/* network statistics */
#define NETCONFIG_NETWORK_STATISTICS_PATH	"/net/netconfig/network_statistics"
#define NETCONFIG_NETWORK_STATISTICS_INTERFACE	"net.netconfig.network_statistics"

#define GET_WIFI_TOTAL_TX_BYTES "GetWifiTotalTxBytes"
#define GET_WIFI_TOTAL_RX_BYTES "GetWifiTotalRxBytes"
#define GET_WIFI_LAST_TX_BYTES "GetWifiLastTxBytes"
#define GET_WIFI_LAST_RX_BYTES "GetWifiLastRxBytes"
#define RESET_CELLULAR_TOTAL_TX_BYTES  "ResetCellularTotalTxBytes"
#define RESET_CELLULAR_TOTAL_RX_BYTES "ResetCellularTotalRxBytes"
#define RESET_CELLULAR_LAST_TX_BYTES "ResetCellularLastTxBytes"
#define RESET_CELLULAR_LAST_RX_BYTES "ResetCellularLastRxBytes"
#define RESET_WIFI_TOTAL_TX_BYTES "ResetWifiTotalTxBytes"
#define RESET_WIFI_TOTAL_RX_BYTES "ResetWifiTotalRxBytes"
#define RESET_WIFI_LAST_TX_BYTES "ResetWifiLastTxBytes"
#define RESET_WIFI_LAST_RX_BYTES "ResetWifiLastRxBytes"

class GDbus {
private:
	GDBusConnection *m_pConnection;
	GCancellable *m_pCancellable;
public:
	GDbus();
	~GDbus();
	error_e Create(void);
	error_e Destroy(void);
	GDBusConnection *GetConnection(void);
	GCancellable *GetCancellable(void);
	error_e ConvertErrorStringToEnum(const char *error);
	GVariant *InvokeMethod(const char *dest, const char *path,
		const char *iface_name, const char *method, GVariant *params, error_e *dbus_error);
	error_e InvokeMethodNonblock(const char *dest, const char *path,
		const char *iface_name, const char *method, GVariant *params, int timeout,
		GAsyncReadyCallback notify_func, void *user_data);
	GVariant *InvokeMethod_with_fd(GUnixFDList *fd_list, const char *dest, const char *path,
			const char *iface_name, const char *method, GVariant *params, error_e *dbus_error);
};

#endif /* __NET_CONFIG_GDBUS_H__ */
