/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <gmock/gmock.h>
#include <gtest/gtest.h>
#include <stdint.h>

#include "mptcp.h"

Mptcp::Mptcp()
{
	Create();
}

Mptcp::~Mptcp()
{
	Destroy();
}

error_e Mptcp::MptcpSupported(bool *supported)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_MPTCP_PATH,
		NETCONFIG_MPTCP_INTERFACE,
		MPTCP_SUPPORTED,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(b)", supported);
	g_variant_unref(message);

	return ERROR_NONE;
}

error_e Mptcp::MptcpSetEnable(int enabled)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_MPTCP_PATH,
		NETCONFIG_MPTCP_INTERFACE,
		MPTCP_SET_ENABLE,
		g_variant_new("(i)", enabled),
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e Mptcp::MptcpGetEnabled(int *enabled)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_MPTCP_PATH,
		NETCONFIG_MPTCP_INTERFACE,
		MPTCP_GET_ENABLED,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(i)", enabled);
	g_variant_unref(message);

	return ERROR_NONE;
}

error_e Mptcp::MptcpSetPathManager(const char *path)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_MPTCP_PATH,
		NETCONFIG_MPTCP_INTERFACE,
		MPTCP_SET_PATH_MANAGER,
		g_variant_new("(s)", path),
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e Mptcp::MptcpGetPathManager(char *path)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_MPTCP_PATH,
		NETCONFIG_MPTCP_INTERFACE,
		MPTCP_GET_PATH_MANAGER,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(s)", path);
	g_variant_unref(message);

	return ERROR_NONE;
}

error_e Mptcp::MptcpSetScheduler(const char *sched)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_MPTCP_PATH,
		NETCONFIG_MPTCP_INTERFACE,
		MPTCP_SET_SCHEDULER,
		g_variant_new("(s)", sched),
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e Mptcp::MptcpGetScheduler(char *sched)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_MPTCP_PATH,
		NETCONFIG_MPTCP_INTERFACE,
		MPTCP_GET_SCHEDULER,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(s)", sched);
	g_variant_unref(message);

	return ERROR_NONE;
}

