/*
 * Copyright (c) 2017 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <stdio.h>
#include <stdlib.h>
#include <iostream>
#include <gmock/gmock.h>
#include <gtest/gtest.h>
#include <stdint.h>

#include "netstat.h"

NetStat::NetStat()
{
	Create();
}

NetStat::~NetStat()
{
	Destroy();
}

error_e NetStat::GetWifiTotalTxBytes(void)
{
	unsigned long long tx_bytes = 0;
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		GET_WIFI_TOTAL_TX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(t)", &tx_bytes);
	g_variant_unref(message);

	GLOGD("Succeeded to get wifi total tx bytes %llu", tx_bytes);

	return ERROR_NONE;
}

error_e NetStat::GetWifiTotalRxBytes(void)
{
	unsigned long long rx_bytes = 0;
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		GET_WIFI_TOTAL_RX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(t)", &rx_bytes);
	g_variant_unref(message);

	GLOGD("Succeeded to get wifi total rx bytes %llu", rx_bytes);

	return ERROR_NONE;
}

error_e NetStat::GetWifiLastTxBytes(void)
{
	unsigned long long tx_bytes = 0;
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		GET_WIFI_LAST_TX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(t)", &tx_bytes);
	g_variant_unref(message);

	GLOGD("Succeeded to get wifi last tx bytes %llu", tx_bytes);

	return ERROR_NONE;
}

error_e NetStat::GetWifiLastRxBytes(void)
{
	unsigned long long rx_bytes = 0;
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		GET_WIFI_LAST_RX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_get(message, "(t)", &rx_bytes);
	g_variant_unref(message);

	GLOGD("Succeeded to get wifi last rx bytes %llu", rx_bytes);

	return ERROR_NONE;
}

error_e NetStat::ResetCellularTotalTxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_CELLULAR_TOTAL_TX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e NetStat::ResetCellularTotalRxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_CELLULAR_TOTAL_RX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e NetStat::ResetCellularLastTxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_CELLULAR_LAST_TX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e NetStat::ResetCellularLastRxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_CELLULAR_LAST_RX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e NetStat::ResetWifiLastTxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_WIFI_LAST_TX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e NetStat::ResetWifiLastRxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_WIFI_LAST_RX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e NetStat::ResetWifiTotalTxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_WIFI_TOTAL_TX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}

error_e NetStat::ResetWifiTotalRxBytes(void)
{
	GVariant *message = NULL;
	error_e error = ERROR_NONE;

	message = InvokeMethod(NETCONFIG_SERVICE,
		NETCONFIG_NETWORK_STATISTICS_PATH,
		NETCONFIG_NETWORK_STATISTICS_INTERFACE,
		RESET_WIFI_TOTAL_RX_BYTES,
		NULL,
		&error);

	if (message == NULL) {
		GLOGD("Failed to invoke dbus method");
		return error;
	}

	g_variant_unref(message);

	return ERROR_NONE;
}
