/*
 * Network Configuration Module
 *
 * Copyright (c) 2000 - 2012 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __NETCONFIG_WIFI_CONFIG_H__
#define __NETCONFIG_WIFI_CONFIG_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "wifi.h"

// Configuration Field key
#define WIFI_CONFIG_NAME				"Name"
#define WIFI_CONFIG_SSID				"SSID"
#define WIFI_CONFIG_PASSPHRASE		"Passphrase"
#define WIFI_CONFIG_SECURITY_TYPE		"Security"
#define WIFI_CONFIG_FAVORITE			"Favorite"
#define WIFI_CONFIG_AUTOCONNECT		"AutoConnect"
#define WIFI_CONFIG_HIDDEN				"Hidden"
#define WIFI_CONFIG_CREATED				"Created"
#define WIFI_CONFIG_IPV4_METHOD			"IPv4.method"
#define WIFI_CONFIG_IPV6_METHOD			"IPv6.method"
#define WIFI_CONFIG_IPV4_DNS_METHOD			"Nameservers.IPv4method"
#define WIFI_CONFIG_IPV6_DNS_METHOD			"Nameservers.IPv6method"
#define WIFI_CONFIG_IPV4_ADDRESS			"IPv4.local_address"
#define WIFI_CONFIG_IPV4_SUBNET_MASK			"IPv4.netmask_prefixlen"
#define WIFI_CONFIG_IPV6_PREFIX_LEN			"IPv6.netmask_prefixlen"
#define WIFI_CONFIG_IPV4_GATEWAY_ADDRESS		"IPv4.gateway"
#define WIFI_CONFIG_DNS_ADDRESS			"Nameservers"
#define WIFI_CONFIG_FAILURE			"Failure"
#define WIFI_CONFIG_PROXYADDRESS		"ProxyAddress"
#define WIFI_CONFIG_PROXY_METHOD		"Proxy.Method"
#define WIFI_CONFIG_PROXY_SERVER		"Proxy.Servers"
#define WIFI_CONFIG_EAP_ANONYMOUS_IDENTITY			"AnonymousIdentity"
#define WIFI_CONFIG_EAP_CACERT			"CACertFile"
#define WIFI_CONFIG_EAP_CLIENTCERT			"ClientCertFile"
#define WIFI_CONFIG_EAP_PRIVATEKEY		"PrivateKeyFile"
#define WIFI_CONFIG_EAP_PRIVATEKEY_PASSWORD	"PrivateKeyPassword"
#define WIFI_CONFIG_EAP_IDENTITY		"Identity"
#define WIFI_CONFIG_EAP_TYPE		"EapType"
#define WIFI_CONFIG_EAP_AUTH_TYPE	"EapAuthType"
#define WIFI_CONFIG_EAP_SUBJECT_MATCH	"SubjectMatch"

/**
 * This enumeration is used in frame id value in vsie method calls
 */
typedef enum {
	NETCONFIG_VSIE_FRAME_ASSOC_REQ = 13,
	NETCONFIG_VSIE_FRAME_PROBE_REQ = 14,
	NETCONFIG_VSIE_FRAME_REASSOC = 15,
	NETCONFIG_VSIE_FRAME_AUTH_REQ = 16,
	NETCONFIG_VSIE_FRAME_ACTION = 17,
	NETCONFIG_VSIE_FRAME_MAX
} netconfig_vsie_frames_e;

gboolean	wifi_config_get_config_id(const gchar *service_profile, gchar **config_id);
gboolean	wifi_config_remove_configuration(const gchar *config_id);
gboolean	wifi_config_save_configuration(const gchar *config_id, GKeyFile *keyfile);
gboolean	wifi_config_get_group_name(const gchar *prefix, const gchar *config_id, gchar **group_name);
int __netconfig_hex_str_to_bin(const char *hex, unsigned char *buf, size_t len);
int __netconfig_hex_to_byte(const char *hex);
int __netconfig_hex_char_to_num(char c);

gboolean	handle_get_config_ids(Wifi *wifi, GDBusMethodInvocation *context);
gboolean	handle_load_configuration(Wifi *wifi, GDBusMethodInvocation *context, const gchar *config_id);
gboolean	handle_save_configuration(Wifi *wifi, GDBusMethodInvocation *context, const gchar *config_id, GVariant *configuration);
gboolean	handle_load_eap_configuration(Wifi *wifi, GDBusMethodInvocation *context, const gchar *config_id);
gboolean	handle_save_eap_configuration(Wifi *wifi, GDBusMethodInvocation *context, const gchar *config_id, GVariant *configuration);
gboolean	handle_remove_configuration(Wifi *wifi, GDBusMethodInvocation *context, const gchar *config_id);
gboolean	handle_set_config_field(Wifi *wifi, GDBusMethodInvocation *context, const gchar *config_id, const gchar *key, const gchar *value);
gboolean	handle_get_config_passphrase(Wifi *wifi, GDBusMethodInvocation *context, const gchar *config_id);

gboolean handle_add_vsie(Wifi *wifi, GDBusMethodInvocation *context, int frame_id, const gchar *vsie);
gboolean handle_get_vsie(Wifi *wifi, GDBusMethodInvocation *context, int frame_id);
gboolean handle_remove_vsie(Wifi *wifi, GDBusMethodInvocation *context, int frame_id, const gchar *vsie);

#ifdef __cplusplus
}
#endif

#endif /* __NETCONFIG_WIFI_CONFIG_H */
