/*
 * Network Configuration Module
 *
 * Copyright (c) 2000 - 2012 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#ifndef __NETCONFIG_WIFI_NETLINK_SCAN_H__
#define __NETCONFIG_WIFI_NETLINK_SCAN_H__

#ifdef __cplusplus
extern "C" {
#endif

#include "wifi.h"

#define NETCONFIG_SSID_LEN			32
#define NETCONFIG_BSSID_LEN			17
#define NETCONFIG_MAX_VSIE_LEN			255
#define NETCONFIG_VENDOR_SPECIFIC_ID		221

#define NL80211_CMD_SCAN_ABORTED		35
#define NL80211_CMD_GET_SCAN			32
#define NL80211_CMD_TRIGGER_SCAN		33
#define NL80211_CMD_NEW_SCAN_RESULTS		34
#define NL80211_BSS_BSSID			1
#define NL80211_BSS_FREQUENCY			2
#define NL80211_BSS_CAPABILITY			5
#define NL80211_BSS_INFORMATION_ELEMENTS	6
#define NL80211_BSS_SIGNAL_MBM			7
#define NL80211_BSS_MAX				15
#define NL80211_ATTR_BSS			47
#define NL80211_ATTR_IFINDEX			3
#define NL80211_ATTR_IE				42
#define NL80211_ATTR_SCAN_SSIDS			45
#define NL80211_ATTR_MAX			221

#define WLAN_CAPABILITY_PRIVACY			(1<<4)

struct bss_scan_info_t {
	char bssid[NETCONFIG_BSSID_LEN+1];
	char ssid[NETCONFIG_SSID_LEN+1];
	GSList* vsie_list;
	int ssid_len;
	int freq;
	int signal;
	int security_type;
	int encryption_type;
};

struct netconfig_netlink_scan_results {
    int done;
    int aborted;
};

struct netconfig_netlink_scan_handler_args {
    const char *group;
    int id;
};

typedef struct {
	int id;
	int if_index;
	struct nl_sock *socket;
	struct nl_msg *msg;
} netconfig_nl_global;

void __netconfig_notify_netlink_scan_done(void);
int handle_netlink_scan(Wifi *wifi, GDBusMethodInvocation *context, GVariant *params);

#ifdef __cplusplus
}
#endif

#endif /* __NETCONFIG_WIFI_NETLINK_SCAN_H__ */
