#include <glib.h>
#include <sys/sysctl.h>
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <unistd.h>

#include "mptcp-internal.h"
#include "log.h"

#define NET_PROC_SYS_NET_MPTCP	"/proc/sys/net/mptcp/"
#define NET_PROC_SYS_NET_MPTCP_VALUE_MAX_SIZE	15

static gboolean __write_mptcp_parameter(const char* key, const char* value)
{
	char path[50];
	int fd = -1;

	snprintf(path, sizeof(path), NET_PROC_SYS_NET_MPTCP"%s", key);

	fd = open(path, O_RDWR);
	if (fd < 0) {
		ERR("Fail to open %s", path);
		return FALSE;
	}

	DBG("write mptcp parameter. len: %zd, value: %s", strlen(value), value);
	if (write(fd, value, strlen(value)) < 0) {
		ERR("Fail to write %s to %s", value, path);
		close(fd);
		return FALSE;
	}

	close(fd);
	return TRUE;
}

static char* __read_mptcp_parameter(const char* key)
{
	char path[50];
	int fd = -1;
	int len = -1;
	char buf[NET_PROC_SYS_NET_MPTCP_VALUE_MAX_SIZE];

	snprintf(path, sizeof(path), NET_PROC_SYS_NET_MPTCP"%s", key);

	fd = open(path, O_RDWR);
	if (fd < 0) {
		ERR("Fail to open %s", path);
		return NULL;
	}

	if ((len = read(fd, buf, NET_PROC_SYS_NET_MPTCP_VALUE_MAX_SIZE)) < 0) {
		ERR("Fail to read %s", path);
		close(fd);
		return NULL;
	}

	if (len < 1) {
		ERR("Fail to read");
		close(fd);
		return NULL;
	}

	buf[len - 1] = '\0';

	DBG("read mptcp parameter. len: %d, value: %s", len, buf);
	close(fd);
	return g_strndup(buf, strlen(buf));
}

gboolean mptcp_supported()
{
	return g_file_test(NET_PROC_SYS_NET_MPTCP, G_FILE_TEST_EXISTS);
}

gboolean mptcp_set_enabled(gint enable)
{
	const char* sysctlname = "mptcp_enabled";
	char buf[2];
	if (enable != 0 && enable != 1 && enable != 2) {
		ERR("Invalid parameter enable %d", enable);
		return FALSE;
	}

	snprintf(buf, 2, "%d", enable);
	return __write_mptcp_parameter(sysctlname, buf);
}

gint mptcp_get_enabled()
{
	const char* sysctlname = "mptcp_enabled";
	char* buf;
	int enabled = -1;

	if ((buf = __read_mptcp_parameter(sysctlname)) == NULL)  {
		ERR("Fail to read %s", sysctlname);
		return -1;
	}

	enabled = atoi(buf);
	g_free(buf);

	return enabled;
}

gboolean mptcp_set_path_manager(const gchar* pm)
{
	const char* sysctlname = "mptcp_path_manager";
	return __write_mptcp_parameter(sysctlname, pm);
}

gchar* mptcp_get_path_manager()
{
	const char* sysctlname = "mptcp_path_manager";
	return __read_mptcp_parameter(sysctlname);
}

gboolean mptcp_mptcp_set_scheduler(const gchar* scheduler)
{
	const char* sysctlname = "mptcp_scheduler";
	return __write_mptcp_parameter(sysctlname, scheduler);
}

gchar* mptcp_get_scheduler()
{
	const char* sysctlname = "mptcp_scheduler";
	return __read_mptcp_parameter(sysctlname);
}

