/*
 * Network Extension Module
 *
 * Copyright (c) 2000 - 2012 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <errno.h>
#include <vconf.h>
#include <vconf-keys.h>

#include "log.h"
#include "util.h"
#include "neterror.h"
#include "netdbus.h"
#include "netsupplicant.h"
#include "wifi-state.h"
#include "wifi-extension.h"


gboolean handle_flush_bss(Wifi *wifi, GDBusMethodInvocation *context)
{
	DBG("Wi-Fi flush bss");

	g_return_val_if_fail(wifi != NULL, TRUE);

	GDBusConnection *connection = NULL;
	char *if_path = NULL;

	if_path = netconfig_wifi_get_supplicant_interface();
	if (if_path == NULL) {
		netconfig_error_dbus_method_return(context, NETCONFIG_ERROR_INTERNAL, "FailFlushBss");
		DBG("Fail to get wpa_supplicant DBus path");
		return TRUE;
	}

	connection = netdbus_get_connection();
	if (connection == NULL) {
		netconfig_error_dbus_method_return(context, NETCONFIG_ERROR_INTERNAL, "FailFlushBss");
		ERR("Failed to get netdbus connection");
		g_free(if_path);
		return TRUE;
	}


	g_dbus_connection_call(connection,
			SUPPLICANT_SERVICE,
			if_path,
			SUPPLICANT_INTERFACE ".Interface",
			"FlushBSS",
			g_variant_new("(u)", 0),
			NULL,
			G_DBUS_CALL_FLAGS_NONE,
			10 * 1000,
			netdbus_get_cancellable(),
			NULL,
			NULL);

	g_free(if_path);
	wifi_complete_flush_bss(wifi, context);
	return TRUE;
}
